AssemblyError

Enum AssemblyError 

#[non_exhaustive]
pub enum AssemblyError {
Show 17 variants SourceBoneOutOfBounds { bone: BoneId, bone_count: usize, }, AmbiguousSourceName { name: String, first: BoneId, second: BoneId, }, AmbiguousBaseName { name: String, first: BoneId, second: BoneId, }, MissingBaseBone { source_bone: BoneId, name: String, }, AmbiguousSelectedName { name: String, first: BoneId, second: BoneId, }, SelectedBoneOutOfBounds { bone: BoneId, bone_count: usize, }, MissingSelectedName { name: String, }, AmbiguousRemovalName { name: String, first: BoneId, second: BoneId, }, EntireSkeletonSelected, RemovalTrackReference { clip_index: usize, track_index: usize, bone: BoneId, }, RemovalMeshInstanceReference { instance_index: usize, bone: BoneId, }, RemovalSkinJointReference { instance_index: usize, joint_index: usize, bone: BoneId, }, RemovalBoneInverseBindReference { bone: BoneId, }, RemovalSourceSkinReference { source_skin_index: usize, source_node_index: usize, bone: BoneId, }, RemovalSceneRootOutOfBounds { scene_index: usize, root_index: usize, bone: BoneId, }, RemovalPlanDocumentMismatch, InvalidRemovalDocument { violation: DocumentShapeError, },
}
Failure while resolving an exact bone name for an assembly operation.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


SourceBoneOutOfBounds

A track references a source bone outside its skeleton.

Fields

bone: BoneId

Referenced source bone index.

bone_count: usize

Number of source bones.



AmbiguousSourceName

More than one source bone has a referenced exact name.

Fields

name: String

Ambiguous name.

first: BoneId

First source bone with this name.

second: BoneId

Another source bone with this name.



AmbiguousBaseName

More than one destination bone has a referenced exact name.

Fields

name: String

Ambiguous name.

first: BoneId

First base bone with this name.

second: BoneId

Another base bone with this name.



MissingBaseBone

A referenced source-bone name is absent from the base skeleton.

Fields

source_bone: BoneId

Referenced source bone index.

name: String

Missing exact name.



AmbiguousSelectedName

A supplied named-bone selection is ambiguous in the skeleton.

Fields

name: String

Ambiguous name.

first: BoneId

First matching bone.

second: BoneId

Another matching bone.



SelectedBoneOutOfBounds

A caller-selected completion target is outside the base skeleton.

Fields

bone: BoneId

Invalid selected bone.

bone_count: usize

Number of base bones.



MissingSelectedName

A requested node name is absent from the assembled skeleton.

Fields

name: String

Missing exact node name.



AmbiguousRemovalName

A requested node name occurs more than once in the assembled skeleton.

Fields

name: String

Ambiguous exact node name.

first: BoneId

First matching node.

second: BoneId

Another matching node.



EntireSkeletonSelected

Removing the selected closures would leave no skeleton nodes.



RemovalTrackReference

A final animation track still targets a selected closure.

Fields

clip_index: usize

Final clip index.

track_index: usize

Final track index.

bone: BoneId

Referenced node.



RemovalMeshInstanceReference

A mesh instance is attached to a selected closure.

Fields

instance_index: usize

Mesh-instance index.

bone: BoneId

Referenced node.



RemovalSkinJointReference

A skin joint belongs to a selected closure.

Fields

instance_index: usize

Mesh-instance index.

joint_index: usize

Joint slot.

bone: BoneId

Referenced node.



RemovalBoneInverseBindReference

A selected node carries bone-level inverse-bind evidence.

Fields

bone: BoneId

Referenced node.



RemovalSourceSkinReference

Complete source-skin evidence references a selected closure.

Fields

source_skin_index: usize

Stable source-skin index.

source_node_index: usize

Stable source-node index.

bone: BoneId

Referenced normalized node.



RemovalSceneRootOutOfBounds

A declared scene root is outside the skeleton.

Fields

scene_index: usize

Scene index.

root_index: usize

Root slot within the scene.

bone: BoneId

Missing node index.



RemovalPlanDocumentMismatch

The document no longer has the skeleton used to build a removal plan.



InvalidRemovalDocument

The strict input or projected document shape is invalid.

Fields

violation: DocumentShapeError

Strict structural violation.