CollectionManifestError

Enum CollectionManifestError 

#[non_exhaustive]
pub enum CollectionManifestError { InvalidText { field: &'static str, max: usize, }, InvalidIdentifier { field: &'static str, }, TooManyRows { field: &'static str, found: usize, max: usize, }, EmptyRows { field: &'static str, }, TooManyMembers { found: usize, max: usize, }, TooMuchWork { found: usize, max: usize, }, Duplicate { field: &'static str, value: String, }, DanglingSource { clip_id: String, source_key: String, }, DanglingMember { set_id: String, member: String, }, TooFewMembers { set_id: String, found: usize, }, OutsideCollectionNamespace { field: &'static str, value: String, collection_id: String, }, InvalidDigest, }
A V1 collection manifest was malformed or exceeded a frozen bound.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InvalidText

A required text field was empty or exceeded its byte bound.

Fields

field: &'static str

Stable field path.

max: usize

Maximum accepted byte length.



InvalidIdentifier

An identifier did not satisfy the V1 lowercase ASCII grammar.

Fields

field: &'static str

Stable field path.



TooManyRows

A bounded row collection exceeded its limit.

Fields

field: &'static str

Stable collection field.

found: usize

Observed row count.

max: usize

Maximum accepted count.



EmptyRows

A required source or clip array was empty.

Fields

field: &'static str

Stable collection field.



TooManyMembers

Aggregate member work exceeded its V1 limit.

Fields

found: usize

Observed aggregate member count.

max: usize

Maximum accepted count.



TooMuchWork

Aggregate declaration work exceeded its V1 limit.

Fields

found: usize

Observed aggregate work count.

max: usize

Maximum accepted work count.



Duplicate

A source key, clip id, set id, binding, or member was repeated.

Fields

field: &'static str

Stable duplicate category.

value: String

Stable rejected value.



DanglingSource

A clip named an undeclared source key.

Fields

clip_id: String

Logical clip identifier.

source_key: String

Missing source key.



DanglingMember

A runtime set named an undeclared logical clip id.

Fields

set_id: String

Runtime-set identifier.

member: String

Missing logical clip id.



TooFewMembers

A runtime set did not contain at least two distinct members.

Fields

set_id: String

Runtime-set identifier.

found: usize

Received member count.



OutsideCollectionNamespace

A clip or runtime-set id escaped the declared collection namespace.

Fields

field: &'static str

Stable field path.

value: String

Rejected id.

collection_id: String

Declared collection id.



InvalidDigest

A digest pin was not exactly 64 lowercase hexadecimal characters.