pub struct CollectionSourceV1 { /* private fields */ }Expand description
One source declaration, with safe relative locators but no host I/O state.
Implementations
Sourceimpl CollectionSourceV1
impl CollectionSourceV1
Sourcepub fn new(
key: CollectionSourceKeyV1,
path: DependencyResourceKeyV1,
config: Option<DependencyResourceKeyV1>,
expected_sha256: Option<CollectionDigestPinV1>,
) -> Self
pub fn new( key: CollectionSourceKeyV1, path: DependencyResourceKeyV1, config: Option<DependencyResourceKeyV1>, expected_sha256: Option<CollectionDigestPinV1>, ) -> Self
Construct one source declaration.
Sourcepub fn key(&self) -> &CollectionSourceKeyV1
pub fn key(&self) -> &CollectionSourceKeyV1
Manifest-local source key.
Sourcepub fn path(&self) -> &DependencyResourceKeyV1
pub fn path(&self) -> &DependencyResourceKeyV1
Safe source locator resolved under the optional input root.
Sourcepub fn config(&self) -> Option<&DependencyResourceKeyV1>
pub fn config(&self) -> Option<&DependencyResourceKeyV1>
Optional safe config locator resolved under the manifest directory.
Sourcepub fn expected_sha256(&self) -> Option<&CollectionDigestPinV1>
pub fn expected_sha256(&self) -> Option<&CollectionDigestPinV1>
Optional asserted source digest.