#[non_exhaustive]pub enum ContactFragmentError {
SourceTooLarge {
bytes: usize,
limit: usize,
},
InvalidJson {
message: String,
},
InvalidField {
field: &'static str,
message: String,
},
LimitExceeded {
field: &'static str,
found: usize,
limit: usize,
},
CanonicalTooLarge {
limit: usize,
},
}Expand description
Reader or contract violation for contact-fragment V1.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
SourceTooLarge
JSON source exceeded the immutable V1 input cap.
InvalidJson
The source was not valid UTF-8 JSON or used duplicate object members.
InvalidField
A required V1 field was absent, malformed, or an object contained an unknown field.
Fields
LimitExceeded
A frozen V1 row or byte bound was exceeded.
Fields
CanonicalTooLarge
RFC 8785 canonical output could not be represented within the V1 cap.