MeasurementFileError

Enum MeasurementFileError 

#[non_exhaustive]
pub enum MeasurementFileError {
Show 39 variants InvalidFileShape { reason: String, }, MissingPath, MissingInput, MissingSha256, InvalidSha256, MissingBytes, MissingMeasurements, MissingPredictionProvenance, UnexpectedPredictionProvenance, MissingChecks, UnexpectedChecks, TooManyChecks { found: usize, limit: usize, }, PredictionPrimaryInputMismatch, InvalidPredictionProvenance { source: PredictionContractError, }, InvalidPredictionProvenanceShape { reason: String, }, PredictionWithoutProvenance { check_index: usize, }, InvalidPrediction { check_index: usize, source: PredictionContractError, }, InvalidPredictionShape { check_index: usize, reason: String, }, InvalidPredictionLifecycle { check_index: usize, reason: &'static str, }, TooManyPredictionFacets { found: usize, limit: usize, }, TooManyPredictionBasisReferences { found: usize, limit: usize, }, TooMuchPredictionText { found: usize, limit: usize, }, PredictionAccountingOverflow, MissingMeasurementVersion, UnsupportedMeasurementVersion { found: u32, }, WrongMeasurementIdentity, MissingClips, MissingMaterialResourceCoverage, MissingMaterialDefinitions, MissingTextures, MissingImages, MissingSkeletonSourceCoverage, MissingSkeletonNodes, MissingSkins, MissingMeshDefinitions, MissingNodeInstances, MissingScenes, InvalidMeasurementsShape { reason: String, }, InvalidMeasurements { source: MeasurementContractError, },
}
One measurement-report file record failed validation.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InvalidFileShape

The bounded file record could not be decoded after the outer v10 identity was accepted.

Fields

reason: String

Stable serde diagnostic for the malformed nested record.



MissingPath

The file record omitted its source path.



MissingInput

The file record omitted its source-byte identity.



MissingSha256

The source-byte identity omitted its SHA-256 digest.



InvalidSha256

The source-byte identity uses a malformed SHA-256 digest.



MissingBytes

The source-byte identity omitted its byte count.



MissingMeasurements

The file record omitted its nested measurement contract.



MissingPredictionProvenance

A lint file omitted its required nullable provenance field.



UnexpectedPredictionProvenance

A measure file carried lint-only prediction provenance.



MissingChecks

A lint file omitted its check array.



UnexpectedChecks

A measure file carried lint-only check records.



TooManyChecks

A lint file exceeded the immutable per-file check bound.

Fields

found: usize

Supplied check count.

limit: usize

Immutable output-v10 limit.



PredictionPrimaryInputMismatch

File and prediction-provenance primary identities differ.



InvalidPredictionProvenance

File-scoped prediction provenance violated its immutable contract.

Fields

source: PredictionContractError

Typed nested provenance failure.



InvalidPredictionProvenanceShape

The serialized provenance object could not be decoded as the strict V1 wire.

Fields

reason: String

Stable serde diagnostic for the malformed nested object.



PredictionWithoutProvenance

One check carried a prediction without file provenance.

Fields

check_index: usize

Zero-based check index.



InvalidPrediction

One check’s prediction evidence violated its immutable contract.

Fields

check_index: usize

Zero-based check index.

source: PredictionContractError

Typed nested prediction failure.



InvalidPredictionShape

One serialized check or prediction object could not be decoded as the strict V1 wire.

Fields

check_index: usize

Zero-based check index.

reason: String

Stable serde diagnostic for the malformed nested object.



InvalidPredictionLifecycle

One check’s prediction attachment contradicts the sole check lifecycle.

Fields

check_index: usize

Zero-based check index.

reason: &'static str

Stable relationship failure.



TooManyPredictionFacets

Aggregate prediction facets exceeded the per-file V1 bound.

Fields

found: usize

Supplied facet count.

limit: usize

Immutable V1 limit.



TooManyPredictionBasisReferences

Aggregate prediction basis rows exceeded the per-file V1 bound.

Fields

found: usize

Supplied basis-row count.

limit: usize

Immutable V1 limit.



TooMuchPredictionText

Aggregate prediction/provenance retained text exceeded the per-file bound.

Fields

found: usize

Supplied UTF-8 byte count.

limit: usize

Immutable V1 limit.



PredictionAccountingOverflow

Checked prediction accounting overflowed.



MissingMeasurementVersion

The nested measurement contract omitted its version.



UnsupportedMeasurementVersion

The nested measurement contract uses an unsupported version.

Fields

found: u32

Version found in the nested contract.



WrongMeasurementIdentity

The nested contract does not carry the immutable measurement identity.



MissingClips

The nested contract omitted its clip-measurement map.



MissingMaterialResourceCoverage

The nested contract omitted material resource coverage.



MissingMaterialDefinitions

The nested contract omitted its material definition array.



MissingTextures

The nested contract omitted its texture array.



MissingImages

The nested contract omitted its image array.



MissingSkeletonSourceCoverage

The nested contract omitted skeleton source coverage.



MissingSkeletonNodes

The nested contract omitted its source skeleton-node array.



MissingSkins

The nested contract omitted its source skin array.



MissingMeshDefinitions

The nested contract omitted its mesh-definition array.



MissingNodeInstances

The nested contract omitted its node-instance array.



MissingScenes

The nested contract omitted its scene array.



InvalidMeasurementsShape

The nested measurements object could not be decoded after prediction-independent validation completed.

Fields

reason: String

Stable serde diagnostic for the malformed nested measurements.



InvalidMeasurements

The nested measurement values do not satisfy the current contract.

Fields

source: MeasurementContractError

Measurement validation failure.