pub enum DependencyResourceUnavailableReasonV1 {
ResourceRootUnavailable,
Missing,
Unreadable,
ResourceBudgetExceeded,
}Expand description
Why a safe declaration could not be assigned a content identity.
Variants
The byte-loading caller supplied no trusted resource root.
Missing
The accepted relative resource does not exist.
Unreadable
The accepted relative resource could not be opened or read.
ResourceBudgetExceeded
A closure capture budget stopped this resource.