#[non_exhaustive]pub enum CollectionDirectionalSpeedEvaluationControlError {
OverBudgetInput,
InvalidBinding,
ContradictoryEvidence,
}Expand description
Invalid/stale/wrong-kind/contradictory input. Ordinary incomplete and not-evaluable sets are represented by successful typed results instead.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
OverBudgetInput
Raw policy or evidence identity exceeds its immutable input cap.
InvalidBinding
Policy did not bind to the evidence manifest/set/kind/member sequence.
ContradictoryEvidence
The strict evidence adapter was contradictory.