pub enum EngineDefaultStatusV1 {
RequiredWithoutDefault,
NotApplicable,
}Expand description
Verified default status of a setting.
Variants
RequiredWithoutDefault
The caller must declare a value because no default is verified.
NotApplicable
Default behavior is irrelevant because the setting does not apply.