pub enum EngineSettingScopeV1 {
Document,
Clip,
}Expand description
Configuration scope of a setting.
Variants
Document
One value governs the imported document and all clips.
Clip
One materialized value is required for each actual clip.