pub struct CheckEvaluation { /* private fields */ }Expand description
Final output-v7 record for one catalog check.
Implementations
Sourceimpl CheckEvaluation
impl CheckEvaluation
Sourcepub fn evaluated(
check_id: &'static str,
output: CheckOutput,
) -> Result<Self, EvaluationError>
pub fn evaluated( check_id: &'static str, output: CheckOutput, ) -> Result<Self, EvaluationError>
Construct a selected, enabled, applicable evaluation from validated check output.
Errors
Returns an error for an empty check id, malformed coverage codes, built-in evidence emitted by an undeclared check, or when a nested finding names a different check.
Sourcepub fn selection(&self) -> SelectionState
pub fn selection(&self) -> SelectionState
Invocation selection state.
Sourcepub fn configuration(&self) -> ConfigurationState
pub fn configuration(&self) -> ConfigurationState
Configuration activation state.
Sourcepub fn applicability(&self) -> Applicability
pub fn applicability(&self) -> Applicability
Applicability to this document/configuration.
Sourcepub fn evaluation(&self) -> EvaluationState
pub fn evaluation(&self) -> EvaluationState
Derive evaluation coverage from activation, completed scopes, and gaps.
Sourcepub fn evaluated_scopes(&self) -> &[EvaluationScope]
pub fn evaluated_scopes(&self) -> &[EvaluationScope]
Stable identifiers for work that completed.
Sourcepub fn gaps(&self) -> &[CoverageGap]
pub fn gaps(&self) -> &[CoverageGap]
Typed reasons work was not evaluated.