#[non_exhaustive]pub enum StaticNodeAabbUnavailableReason {
NoFinitePositions,
SkinnedDeformationExcluded,
NonFiniteTransform,
}Expand description
Why a static node-instance AABB could not be emitted.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NoFinitePositions
The referenced definition has no finite base positions.
SkinnedDeformationExcluded
The instance is skinned, whose node transform is not a static rendered bound under glTF semantics; bind-pose skinning is a separate domain.
NonFiniteTransform
The default/rest world transform or a transformed point was non-finite.