AssetMeasurements

Struct AssetMeasurements 

#[non_exhaustive]
pub struct AssetMeasurements { pub material_resource_coverage: MaterialResourceCoverage, pub material_definitions: Vec<MaterialDefinitionMeasurements>, pub textures: Vec<TextureMeasurements>, pub images: Vec<ImageMeasurements>, pub skeleton_source_coverage: SkeletonSourceCoverage, pub skeleton_nodes: Vec<SkeletonNodeMeasurements>, pub skins: Vec<SkinMeasurements>, pub mesh_definitions: Vec<MeshDefinitionMeasurements>, pub node_instances: Vec<NodeInstanceMeasurements>, pub scenes: Vec<SceneMeasurements>, pub default_scene_index: Option<usize>, }
Static scene-asset evidence nested beside clip measurements.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
material_resource_coverage: MaterialResourceCoverage

Whether material, texture, and image resource tables are complete.

material_definitions: Vec<MaterialDefinitionMeasurements>

Source material definitions in stable source order.

textures: Vec<TextureMeasurements>

Source texture definitions in stable source order.

images: Vec<ImageMeasurements>

Source image definitions in stable source order.

skeleton_source_coverage: SkeletonSourceCoverage

Whether source skeleton identity facts are available.

skeleton_nodes: Vec<SkeletonNodeMeasurements>

Source nodes in source-node order when skeleton coverage is complete.

skins: Vec<SkinMeasurements>

Source skins in source-skin order when skeleton coverage is complete.

mesh_definitions: Vec<MeshDefinitionMeasurements>

Source mesh definitions, including definitions with no node instance.

node_instances: Vec<NodeInstanceMeasurements>

Mesh-bearing source nodes, including nodes outside every scene.

scenes: Vec<SceneMeasurements>

Every declared source scene in source order.

default_scene_index: Option<usize>

Stable source scene index selected as the default, when declared.