SkeletonNodeMeasurements

Struct SkeletonNodeMeasurements 

#[non_exhaustive]
pub struct SkeletonNodeMeasurements { pub node_index: usize, pub name: Option<String>, pub parent_node_index: Option<usize>, pub scene_root_indices: Vec<usize>, pub local_rest: SkeletonNodeLocalRestMeasurements, pub rest_world_matrix: Option<[f32; 16]>, pub rest_world_translation_m: Option<[f32; 3]>, pub rest_world_linear: LinearTransformMeasurements, pub rest_world_matrix_unavailable_reason: Option<SkeletonRestWorldMatrixUnavailableReason>, }
One source node in stable source-node order.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
node_index: usize

Stable source node-array index.

name: Option<String>

Authored node name, when present.

parent_node_index: Option<usize>

Direct source parent, when present.

scene_root_indices: Vec<usize>

Source scenes that explicitly name this node as a scene root, in ascending source-scene order. Scene membership does not alter the node’s local or accumulated rest transform.

local_rest: SkeletonNodeLocalRestMeasurements

Authored node-local rest representation.

rest_world_matrix: Option<[f32; 16]>

Accumulated rest transform from this source root to this node, in column-major order.

rest_world_translation_m: Option<[f32; 3]>

Translation column of Self::rest_world_matrix, in metres in the accumulated source rest-world coordinate domain.

rest_world_linear: LinearTransformMeasurements

Linear-transform facts for the accumulated rest-world matrix. A non-finite classification accompanies an unavailable matrix.

rest_world_matrix_unavailable_reason: Option<SkeletonRestWorldMatrixUnavailableReason>

Present exactly when Self::rest_world_matrix is unavailable.