#[non_exhaustive]pub struct SkinMatrixInversionQuality {
pub reciprocal_condition_number_inf: f64,
}Expand description
Numerical quality of an inverse-bind matrix inversion.
The reciprocal condition number uses the matrix infinity norm over the
linear 3x3 part: 1 / (norm_inf(A) * norm_inf(inverse(A))). It is
scale-free, ranges from zero through one, and approaches zero as the
matrix approaches singularity.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.reciprocal_condition_number_inf: f64Reciprocal infinity-norm condition number of the source linear 3x3.