BoneLoopContinuityMetrics

Struct BoneLoopContinuityMetrics 

#[non_exhaustive]
pub struct BoneLoopContinuityMetrics { pub position_delta_m: f64, pub rotation_delta_deg: f64, pub seam_velocity_delta_mps: f64, pub seam_angular_velocity_delta_degps: f64, }
Model-space loop-continuity measurements for one skeleton bone.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
position_delta_m: f64

Last-sample to first-sample model-space position distance (metres).

rotation_delta_deg: f64

Shortest-path model-space rotation difference (degrees).

seam_velocity_delta_mps: f64

Difference between the model-space linear velocities immediately before and after the wrap (metres per second).

seam_angular_velocity_delta_degps: f64

Difference between the model-space angular velocities immediately before and after the wrap (degrees per second).