pub enum ImageUnavailableReason {
SourceUnavailable,
InvalidDataUri,
UnsupportedContainer,
DecodeFailed,
ResourceLimit,
}Expand description
Why source-image inspection could not produce decoded metadata.
Variants
The source does not make the image payload available to the loader.
InvalidDataUri
A data URI could not be parsed or decoded.
UnsupportedContainer
The image container is not supported for inspection.
DecodeFailed
Supported image bytes could not be decoded.
ResourceLimit
Inspection declined the resource because it exceeded a resource limit.