pub struct SourceSkinAttachment {
pub source_node_index: usize,
pub source_mesh_index: Option<usize>,
}Expand description
One source node that declares use of a source skin.
Fields
source_node_index: usizeStable node-array index of the attachment node.
source_mesh_index: Option<usize>Stable source mesh-definition index, when the node declares a mesh.
This remains present even when the current core mesh importer skips the definition (for example, because it has no triangle-list primitive).