pub enum EngineRootMotionClipMappingStateV1 {
Observed,
ProvenAbsent,
Unavailable,
}Expand description
Loader-established source-to-normalized clip mapping state.
Variants
Observed
The normalized clip index and exact name are retained.
ProvenAbsent
The loader proved that this source row has no normalized clip.
The loader could not establish the mapping.