ResolutionOutcome

Enum ResolutionOutcome 

#[non_exhaustive]
pub enum ResolutionOutcome { Resolved, Coverage, AmbiguousExactMatch, AmbiguousFoldedMatch, RoleCollision, AmbiguousProfile, }
Typed overall result of resolving a configured rig.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Resolved

Every binding considered by the selected profile resolved.



Coverage

A usable, injective role map was produced but one or more bindings did not have a candidate.



AmbiguousExactMatch

One exact binding had more than one candidate.



AmbiguousFoldedMatch

One case-insensitive binding had more than one candidate.



RoleCollision

Two roles would have selected the same bone.



AmbiguousProfile

More than one built-in profile had the same best automatic score.

Implementations

Source

impl ResolutionOutcome

pub const fn as_str(self) -> &'static str

Stable output-contract spelling.