RoleResolutionPolicy

Enum RoleResolutionPolicy 

#[non_exhaustive]
pub enum RoleResolutionPolicy { Exact, AsciiCaseInsensitive, Explicit, }
Stable explanation of how one resolved role matched its delivered bone name.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Exact

A built-in binding matched exactly (including its established namespace-stripped form).



AsciiCaseInsensitive

A built-in binding had no exact candidate and matched one unique ASCII-case-insensitive candidate.



Explicit

An exact user-supplied [rig.roles] binding supplied the name.

Implementations

Source

impl RoleResolutionPolicy

pub const fn as_str(self) -> &'static str

Stable output-contract spelling.