pub enum RawAnimationChannelRowV1 {
Animation {
source_animation_index: u64,
channel_coverage: RawSourceSetCoverageV1,
},
AnimationChannel {
source_animation_index: u64,
source_channel_index: u64,
},
}Expand description
One row in canonical animation-then-channel candidate order.
Variants
Animation
One source animation and its independently observed channel coverage.
Fields

channel_coverage: RawSourceSetCoverageV1Coverage of this animation’s source channel array.
AnimationChannel
One source channel belonging to the immediately preceding animation.
Implementations
Sourceimpl RawAnimationChannelRowV1
impl RawAnimationChannelRowV1
Sourcepub const fn source_animation_index(&self) -> u64
pub const fn source_animation_index(&self) -> u64
Source animation-array index.
Sourcepub const fn source_channel_index(&self) -> Option<u64>
pub const fn source_channel_index(&self) -> Option<u64>
Source channel-array index for a channel row.
Sourcepub const fn channel_coverage(&self) -> Option<RawSourceSetCoverageV1>
pub const fn channel_coverage(&self) -> Option<RawSourceSetCoverageV1>
Independent channel coverage carried by an animation row.