#[non_exhaustive]pub enum AssemblyScaleNamedSelectorResolutionError {
RootNotUnique {
matches: usize,
},
SkinNotUnique {
matches: usize,
},
}Expand description
Why a named assembly scale selector did not resolve exactly once.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
RootNotUnique
The exact normalized name matched zero or multiple source nodes.
SkinNotUnique
The resolved root fully governed zero or multiple source skins.