pub struct AssemblyScaleResolvedNamedSelector {
pub source_skin_index: usize,
pub source_root_node_index: usize,
}Expand description
Format-neutral source indices resolved from one exact named assembly root.
Fields
source_skin_index: usizeThe unique non-empty source skin fully governed by the named root.
source_root_node_index: usizeThe unique source node projected from the named normalized root.