SourceFactsError

Enum SourceFactsError 

#[non_exhaustive]
pub enum SourceFactsError {
Show 13 variants TextTooLong { bytes: usize, limit: usize, }, InvalidLogicalLocator, DuplicateBasisAxis, InvalidLinearUnit, InvalidFramesPerSecond, InvalidTimeRange, ZeroConstructCount, NonCanonicalClipIndex { expected: usize, actual: usize, }, NonCanonicalChannelIndex { source_clip_index: usize, expected: usize, actual: usize, }, NonCanonicalConstructOrder { expected: usize, actual: usize, }, NonCanonicalResourceOrder { expected: usize, actual: usize, }, NormalizedClipIndexOutOfRange { index: usize, clip_count: usize, }, DependencyClosure(DependencyClosureError),
}
Invalid raw-source fact or document-binding invariant.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


TextTooLong

One retained source string exceeds the public V1 limit.

Fields

bytes: usize

Observed UTF-8 byte count.

limit: usize

Public V1 limit.



InvalidLogicalLocator

A provenance locator is outside the generated source-logical vocabulary.



DuplicateBasisAxis

Coordinate basis reuses an unsigned axis.



InvalidLinearUnit

Linear unit is not finite and positive.



InvalidFramesPerSecond

Source frame rate is not finite and positive.



InvalidTimeRange

Source range is non-finite or reversed.



ZeroConstructCount

A positive-presence construct row has no occurrences.



NonCanonicalClipIndex

Source clip rows do not form the canonical zero-based source prefix.

Fields

expected: usize

Expected zero-based source index.

actual: usize

Actual source index.



NonCanonicalChannelIndex

Nested channel rows do not form the canonical zero-based source prefix.

Fields

source_clip_index: usize

Source clip containing the invalid order.

expected: usize

Expected zero-based channel index.

actual: usize

Actual channel index.



NonCanonicalConstructOrder

Construct rows do not form the canonical deterministic prefix.

Fields

expected: usize

Expected zero-based row order.

actual: usize

Actual source order.



NonCanonicalResourceOrder

Resource rows do not form the canonical deterministic prefix.

Fields

expected: usize

Expected zero-based row order.

actual: usize

Actual source order.



NormalizedClipIndexOutOfRange

A source clip maps outside the normalized document.

Fields

index: usize

Invalid normalized clip index.

clip_count: usize

Number of normalized clips.



DependencyClosure(DependencyClosureError)

The dependency closure did not bind to these exact raw facts.