#[non_exhaustive]pub enum ConstantTrackRetentionReason {
ProtectedBone,
InvalidTarget,
SamplingUnavailable,
PoseChanged,
LastWritableTrack,
}Expand description
Reason a constant-track candidate was not removed.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ProtectedBone
The caller identifies this bone as a required authored channel.
InvalidTarget
The track targets no bone in the supplied skeleton.
The original or a trial clip cannot be safely sampled.
PoseChanged
Removing the track changes sampled local TRS or model-space pose data.
LastWritableTrack
Removing the track would leave no writable track in the clip.