DuplicateLoopEndpointError

Enum DuplicateLoopEndpointError 

#[non_exhaustive]
pub enum DuplicateLoopEndpointError { NoTracks, InvalidValueCount { track: usize, key_count: usize, value_count: usize, interpolation: Interpolation, }, InvalidValueStorage { track: usize, }, NonFinite { track: Option<usize>, }, NonIncreasingTime { track: usize, }, TimelineMismatch { track: usize, }, DurationMismatch { track: usize, }, }
Failure while analyzing a duplicate loop endpoint.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


NoTracks

The clip has no tracks.



InvalidValueCount

Stored value count does not exactly match the interpolation mode.

Fields

track: usize

Index of the malformed track.

key_count: usize

Number of authored keys.

value_count: usize

Number of stored values.

interpolation: Interpolation

Interpolation mode that determines values per key.



InvalidValueStorage

A property uses incompatible value storage.

Fields

track: usize

Index of the malformed track.



NonFinite

A duration, key time, or stored value is non-finite.

Fields

track: Option<usize>

Index of the malformed track, or None for clip duration.



NonIncreasingTime

A timeline is not strictly increasing.

Fields

track: usize

Index of the malformed track.



TimelineMismatch

A track differs from the exact common authored timeline.

Fields

track: usize

Index of the mismatching track.



DurationMismatch

A final key time does not equal the declared duration.

Fields

track: usize

Index of the mismatching track.