#[non_exhaustive]pub enum TransitionPoseEvaluationControlError {
WrongDeclarationScope,
InvalidSkeletonBasis(SkeletonBasisError),
InvalidMemberWitness,
ResultTooLarge,
InvalidCollectionMemberWitness,
InvalidCollectionManifestBinding,
}Expand description
Invalid evaluator input is a control error. Incomplete families are normal successful results so callers can emit their immutable contract.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
WrongDeclarationScope
The declaration is collection-owned and needs the deferred collection adapter.
InvalidSkeletonBasis(SkeletonBasisError)
The strict normalized skeleton identity could not be constructed.
InvalidMemberWitness
A declaration member witness did not resolve exactly once in the document.
ResultTooLarge
Even the deterministic bounded result summary could not be serialized.
InvalidCollectionMemberWitness
A prepared collection member no longer agrees with its immutable declaration witness.
InvalidCollectionManifestBinding
The supplied collection authority does not exactly match the declaration.