pub struct TransitionPoseMemberV1 { /* private fields */ }Expand description
Exact resolved member authority retained in a family result.
Implementations
Sourceimpl TransitionPoseMemberV1
impl TransitionPoseMemberV1
Sourcepub const fn take_index(&self) -> u64
pub const fn take_index(&self) -> u64
Witnessed embedded take index.
Sourcepub const fn source_input(&self) -> Option<&InputIdentity>
pub const fn source_input(&self) -> Option<&InputIdentity>
Exact raw source identity when the selected source was available.
Sourcepub const fn source_dependency_closure_identity(
&self,
) -> Option<&DependencyClosureIdentityV1>
pub const fn source_dependency_closure_identity( &self, ) -> Option<&DependencyClosureIdentityV1>
Exact complete dependency-closure identity for this selected source.