MeasurementFileError

Enum MeasurementFileError 

#[non_exhaustive]
pub enum MeasurementFileError {
Show 21 variants MissingPath, MissingInput, MissingSha256, InvalidSha256, MissingBytes, MissingMeasurements, MissingMeasurementVersion, UnsupportedMeasurementVersion { found: u32, }, WrongMeasurementIdentity, MissingClips, MissingMaterialResourceCoverage, MissingMaterialDefinitions, MissingTextures, MissingImages, MissingSkeletonSourceCoverage, MissingSkeletonNodes, MissingSkins, MissingMeshDefinitions, MissingNodeInstances, MissingScenes, InvalidMeasurements { source: MeasurementContractError, },
}
One measurement-report file record failed validation.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


MissingPath

The file record omitted its source path.



MissingInput

The file record omitted its source-byte identity.



MissingSha256

The source-byte identity omitted its SHA-256 digest.



InvalidSha256

The source-byte identity uses a malformed SHA-256 digest.



MissingBytes

The source-byte identity omitted its byte count.



MissingMeasurements

The file record omitted its nested measurement contract.



MissingMeasurementVersion

The nested measurement contract omitted its version.



UnsupportedMeasurementVersion

The nested measurement contract uses an unsupported version.

Fields

found: u32

Version found in the nested contract.



WrongMeasurementIdentity

The nested contract does not carry the immutable measurement identity.



MissingClips

The nested contract omitted its clip-measurement map.



MissingMaterialResourceCoverage

The nested contract omitted material resource coverage.



MissingMaterialDefinitions

The nested contract omitted its material definition array.



MissingTextures

The nested contract omitted its texture array.



MissingImages

The nested contract omitted its image array.



MissingSkeletonSourceCoverage

The nested contract omitted skeleton source coverage.



MissingSkeletonNodes

The nested contract omitted its source skeleton-node array.



MissingSkins

The nested contract omitted its source skin array.



MissingMeshDefinitions

The nested contract omitted its mesh-definition array.



MissingNodeInstances

The nested contract omitted its node-instance array.



MissingScenes

The nested contract omitted its scene array.



InvalidMeasurements

The nested measurement values do not satisfy the current contract.

Fields

source: MeasurementContractError

Measurement validation failure.