#[non_exhaustive]pub enum MeasurementReportError {
MissingOutputVersion,
UnsupportedOutputVersion {
found: u32,
},
WrongOutputIdentity,
MissingCommand,
UnsupportedCommand {
command: String,
},
MissingFiles,
File {
file_index: usize,
source: MeasurementFileError,
},
}Expand description
A typed measurement-report subset failed current-contract validation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MissingOutputVersion
The outer envelope omitted its version.
UnsupportedOutputVersion
The outer envelope uses an unsupported version.
WrongOutputIdentity
The outer envelope does not carry the immutable current identity.
MissingCommand
The outer envelope omitted its command.
UnsupportedCommand
The outer envelope belongs to a command without file measurements.
MissingFiles
The outer envelope omitted its file array.
File
One file record failed validation.
Fields

source: MeasurementFileErrorTyped record-validation failure.
Implementations
Sourceimpl MeasurementReportError
impl MeasurementReportError
Sourcepub fn file_index(&self) -> Option<usize>
pub fn file_index(&self) -> Option<usize>
Zero-based file index for an error in one report record.
Envelope-level errors return None.