pub struct LintFileReport { /* private fields */ }Expand description
One source file and its lint-command evidence.
Implementations
Sourceimpl LintFileReport
impl LintFileReport
Sourcepub fn new(
path: impl Into<String>,
input: InputIdentity,
rig: RigInfo,
checks: Vec<CheckEvaluation>,
measurements: MeasurementContract,
) -> Self
pub fn new( path: impl Into<String>, input: InputIdentity, rig: RigInfo, checks: Vec<CheckEvaluation>, measurements: MeasurementContract, ) -> Self
Construct a lint file report with one record per catalog check.
Sourcepub fn input(&self) -> &InputIdentity
pub fn input(&self) -> &InputIdentity
Immutable identity of the source bytes used to produce this record.
Sourcepub fn checks(&self) -> &[CheckEvaluation]
pub fn checks(&self) -> &[CheckEvaluation]
Check records in catalog order.
Sourcepub fn measurements(&self) -> &MeasurementContract
pub fn measurements(&self) -> &MeasurementContract
Nested measurement evidence.