EngineContractError

Enum EngineContractError 

#[non_exhaustive]
pub enum EngineContractError {
Show 25 variants InvalidSchema { field: &'static str, expected: &'static str, found: String, }, EmptyText { field: &'static str, }, TextTooLong { field: &'static str, found: usize, max: usize, }, TooManyRows { field: &'static str, found: usize, max: usize, }, TooManyAggregateRows { found: usize, max: usize, }, TooMuchAggregateText { found: usize, max: usize, }, ArithmeticOverflow { field: &'static str, }, DuplicateKey { field: &'static str, key: String, }, NonCanonicalOrder { field: &'static str, }, InvalidFactInventory, InvalidFactValue { fact: EngineFactIdV1, }, InvalidAcceptedInputs, InvalidDescriptorDefault { setting: EngineSettingIdV1, }, UnknownSourceFact { source_id: String, fact: EngineFactIdV1, }, SourceReferencesNonKnownFact { source_id: String, fact: EngineFactIdV1, }, UnknownSourceSetting { source_id: String, setting: EngineSettingIdV1, }, UnreferencedKnownFact { fact: EngineFactIdV1, }, UnreferencedSetting { setting: EngineSettingIdV1, }, InvalidSourceTransformPath { reason: &'static str, }, UnknownMaterializedSetting { location: String, setting: EngineSettingIdV1, }, WrongSettingScope { location: String, setting: EngineSettingIdV1, }, NonApplicableSetting { location: String, setting: EngineSettingIdV1, }, WrongSettingDomain { location: String, setting: EngineSettingIdV1, }, MissingRequiredSetting { location: String, setting: EngineSettingIdV1, }, IdentityMismatch { contract: &'static str, },
}
Typed violation of the core-owned profile/settings contract.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InvalidSchema

A contract schema id did not match its immutable V1 value.

Fields

field: &'static str

Field carrying the invalid schema id.

expected: &'static str

Required immutable schema id.

found: String

Supplied schema id.



EmptyText

A required retained string was empty.

Fields

field: &'static str

Invalid field.



TextTooLong

One retained string exceeded the per-value byte limit.

Fields

field: &'static str

Oversized field.

found: usize

Observed UTF-8 byte count.

max: usize

Maximum permitted byte count.



TooManyRows

One collection exceeded the V1 row limit.

Fields

field: &'static str

Oversized collection.

found: usize

Observed row count.

max: usize

Maximum permitted row count.



TooManyAggregateRows

Aggregate profile/settings rows exceeded the V1 limit.

Fields

found: usize

Observed aggregate row count.

max: usize

Maximum permitted aggregate row count.



TooMuchAggregateText

Aggregate retained UTF-8 text exceeded the V1 limit.

Fields

found: usize

Observed aggregate UTF-8 byte count.

max: usize

Maximum permitted aggregate byte count.



ArithmeticOverflow

Checked arithmetic overflowed while accounting bounded work.

Fields

field: &'static str

Counter that overflowed.



DuplicateKey

A set/map-shaped collection contains a duplicate stable key.

Fields

field: &'static str

Collection containing the duplicate.

key: String

Duplicate stable key.



NonCanonicalOrder

A canonical collection is not in its required order.

Fields

field: &'static str

Unordered collection.



InvalidFactInventory

The complete closed fact-id inventory is absent or malformed.



InvalidFactValue

A known fact carries a value from another fact domain.

Fields

fact: EngineFactIdV1

Fact whose value is invalid.



InvalidAcceptedInputs

The accepted-input list is empty, duplicated, or noncanonical.



InvalidDescriptorDefault

A descriptor’s applicability and default state disagree.

Fields

setting: EngineSettingIdV1

Invalid setting descriptor.



UnknownSourceFact

A source references a fact absent from the profile.

Fields

source_id: String

Source id.

fact: EngineFactIdV1

Missing fact id.



SourceReferencesNonKnownFact

A source cites a fact whose state is not known.

Fields

source_id: String

Source id.

fact: EngineFactIdV1

Non-known fact id.



UnknownSourceSetting

A source references a descriptor absent from the profile.

Fields

source_id: String

Source id.

setting: EngineSettingIdV1

Missing setting id.



UnreferencedKnownFact

No primary source supports a known profile fact.

Fields

fact: EngineFactIdV1

Unsupported known fact.



UnreferencedSetting

No primary source supports a setting descriptor.

Fields

setting: EngineSettingIdV1

Unsupported descriptor.



InvalidSourceTransformPath

A source-transform path is malformed.

Fields

reason: &'static str

Stable explanation of the malformed path.



UnknownMaterializedSetting

A materialized setting is absent from the profile.

Fields

location: String

Stable document or clip location.

setting: EngineSettingIdV1

Unknown setting id.



WrongSettingScope

A materialized setting is declared at the wrong scope.

Fields

location: String

Stable document or clip location.

setting: EngineSettingIdV1

Wrong-scope setting id.



NonApplicableSetting

A materialized setting is not applicable to the profile.

Fields

location: String

Stable document or clip location.

setting: EngineSettingIdV1

Non-applicable setting id.



WrongSettingDomain

A materialized value does not match its descriptor domain.

Fields

location: String

Stable document or clip location.

setting: EngineSettingIdV1

Invalid setting id.



MissingRequiredSetting

A required-without-default setting is absent.

Fields

location: String

Stable document or clip location.

setting: EngineSettingIdV1

Missing setting id.



IdentityMismatch

A canonical identity does not match its semantic preimage.

Fields

contract: &'static str

Contract whose digest mismatched.