#[non_exhaustive]pub enum SkeletonNodeLocalRestMeasurements {
Trs {
translation_parent_space_m: [f32; 3],
rotation_xyzw: [f32; 4],
scale: [f32; 3],
},
Matrix {
matrix: [f32; 16],
},
Unavailable {
reason: SkeletonNodeLocalRestUnavailableReason,
},
}Expand description
One finite authored node-local rest representation.
The tagged representation preserves a source matrix as a matrix instead of presenting a decomposition as authored TRS evidence.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Trs
Authored local translation, rotation, and scale.
Fields
Matrix
Authored 4×4 local matrix in column-major order.
The authored transform could not be represented in JSON safely.