#[non_exhaustive]pub struct SkinInverseBindAccessorMeasurements {
pub status: SourceInverseBindAccessorStatus,
pub declared_count: Option<usize>,
pub matrices: Vec<[f32; 16]>,
}Expand description
Source-level read state for one inverse-bind accessor.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.status: SourceInverseBindAccessorStatusWhether the source accessor was absent, readable, empty, short, or unreadable.
declared_count: Option<usize>Declared source accessor count, when an accessor was declared.
matrices: Vec<[f32; 16]>Every readable finite raw matrix in accessor order, including entries beyond the skin’s joint count.