pub fn sample_track(track: &Track, t: f32) -> TrackSampleExpand description
Sample a single track at t with the same semantics the grid uses
(clamp at ends, glTF interpolation, shortest-path slerp).
pub fn sample_track(track: &Track, t: f32) -> TrackSampleSample a single track at t with the same semantics the grid uses
(clamp at ends, glTF interpolation, shortest-path slerp).