PoseGrid

Struct PoseGrid 

pub struct PoseGrid {
    pub times: Vec<f32>,
    /* private fields */
}
Model-space and local poses for every (frame, bone) of one clip.

Fields

times: Vec<f32>

Uniform sample times, times[0] == 0, times[last] == duration.

Implementations

Source

impl PoseGrid

pub fn frame_count(&self) -> usize

Number of sampled frames.

pub fn bone_count(&self) -> usize

Number of bones sampled per frame.

pub fn local(&self, frame: usize, bone: usize) -> Transform

Local-space transform at frame and bone.

Panics

Panics if either index is outside the grid bounds.

pub fn model(&self, frame: usize, bone: usize) -> Mat4

Model-space transform at frame and bone.

Panics

Panics if either index is outside the grid bounds.

pub fn model_position(&self, frame: usize, bone: usize) -> Vec3

Model-space joint position.

Panics

Panics if either index is outside the grid bounds.