pub struct SourceClipFactV1 { /* private fields */ }Expand description
One source animation/stack and its independently covered channel rows.
Implementations
Sourceimpl SourceClipFactV1
impl SourceClipFactV1
Sourcepub fn new(
source_clip_index: usize,
source_name: SourceObservationV1<SourceTextV1>,
normalized_clip_index: SourceObservationV1<usize>,
source_range: SourceObservationV1<SourceTimeRangeV1>,
sampler_range: SourceObservationV1<SourceTimeRangeV1>,
channels: SourceFactSetV1<SourceChannelFactV1>,
) -> Self
pub fn new( source_clip_index: usize, source_name: SourceObservationV1<SourceTextV1>, normalized_clip_index: SourceObservationV1<usize>, source_range: SourceObservationV1<SourceTimeRangeV1>, sampler_range: SourceObservationV1<SourceTimeRangeV1>, channels: SourceFactSetV1<SourceChannelFactV1>, ) -> Self
Construct one source clip/take fact row.
Sourcepub const fn source_clip_index(&self) -> usize
pub const fn source_clip_index(&self) -> usize
Stable source animation/stack index.
Sourcepub const fn source_name(&self) -> &SourceObservationV1<SourceTextV1>
pub const fn source_name(&self) -> &SourceObservationV1<SourceTextV1>
Authored/parser source name, distinct from a normalized synthetic name.
Sourcepub const fn normalized_clip_index(&self) -> &SourceObservationV1<usize>
pub const fn normalized_clip_index(&self) -> &SourceObservationV1<usize>
Mapping into the normalized Document::clips array.
Sourcepub const fn source_range(&self) -> &SourceObservationV1<SourceTimeRangeV1>
pub const fn source_range(&self) -> &SourceObservationV1<SourceTimeRangeV1>
Parser-resolved source stack range, when this source format has one.
Sourcepub const fn sampler_range(&self) -> &SourceObservationV1<SourceTimeRangeV1>
pub const fn sampler_range(&self) -> &SourceObservationV1<SourceTimeRangeV1>
Range derived from exact authored sampler inputs, when applicable.
Sourcepub const fn channels(&self) -> &SourceFactSetV1<SourceChannelFactV1>
pub const fn channels(&self) -> &SourceFactSetV1<SourceChannelFactV1>
Raw channel/property rows and their independent coverage.